- ps
A PathwaySpace class object.
- feature
A single string specifying the feature to project as a
signal. Must match either a feature name (see gs_features(ps)) or
a node attribute (see gs_names(ps)). If a node attribute, make sure
it is of numeric type. If the signal does not come from internal features,
assign it directly using the vertexSignal accessor.
- decay.fun
A signal decay function. Available options include
'Weibull', 'exponential', and 'linear' (see weibullDecay).
Users may also define a custom decay model with at least two arguments,
e.g., function(x, signal) { ... }, which should returns a vector of
projected signals of the same length as x. Additional arguments may
include any variable available as a graph vertex attribute.
- aggregate.fun
A function used to aggregate the projected signals.
It must be provided as a unary function, e.g., function(x) { ... },
which should aggregate a vector of signals to a scalar value.
Available options include 'mean', 'wmean', 'log.wmean', and 'exp.wmean'
(See signalAggregation).
- k
A single positive integer specifying the maximum number of
vertices whose signals contribute to the projection. Defaults to
gs_vcount(ps), i.e. all vertices are considered. Specifically,
at each point in space, the k-top decayed signals are retained
prior to aggregation. Reducing k focuses the projection on the
strongest local signals, filtering out weaker contributions.
- rescale
A logical value indicating whether to rescale
the signal. If the signal >=0, then it will be rescaled to
[0, 1]; if the signal <=0, then it will be rescaled to
[-1, 0]; and if the signal in (-Inf, +Inf), then it will be
rescaled to [-1, 1].
- verbose
A logical value specifying to display detailed
messages (when verbose=TRUE) or not (when verbose=FALSE).
- pdist
Deprecated as of PathwaySpace 1.0.2; this parameter is now
passed internally through decay.fun.