- ps
A PathwaySpace class object.
- colors
A vector of colors.
- bg.color
A single color for background.
- si.color
A single color for silhouette.
(see silhouetteMapping).
- si.alpha
A transparency level in [0, 1], used to adjust the
opacity of the silhouette. This parameter is useful for improving the
perception of a background image, when one is available.
- theme
Name of a custom PathwaySpace theme. These themes
(from 'th0' to 'th3') consist mainly of preconfigured ggplot settings,
which the user can subsequently refine using ggplot2.
- title
A string for the title.
- xlab
The title for the 'x' axis of a 2D-image space.
- ylab
The title for the 'y' axis of a 2D-image space.
- zlab
The title for the 'z' axis of the image signal.
- font.size
A single numeric value passed to plot annotations.
- font.color
A single color passed to plot annotations.
- zlim
The 'z' limits of the plot (a numeric vector with two numbers).
If NULL, limits are determined from the range of the input values.
- slices
A single positive integer value used to split
the image signal into equally-spaced intervals.
- add.grid
A logical value indicating whether to add gridlines to
the image space. However, gridlines will only appear when the image
is decorated with graph silhouettes (see silhouetteMapping).
- grid.color
A color passed to geom_point.
- add.summits
A logical value indicating whether to add contour
lines to 'summits' (when summits are available;
see summitMapping).
- label.summits
A logical value indicating whether to label summits.
- summit.color
A color passed to 'summits'.
- add.marks
A logical value indicating whether to plot vertex labels.
- marks
A vector of vertex names to be highlighted in the
image space. This argument overrides 'add.labels'.
- mark.size
A size argument passed to geom_text.
- mark.color
A color passed to geom_text.
- mark.padding
A box padding argument passed to
geom_text_repel.
- mark.line.width
A line width argument passed to
geom_text_repel.
- use.dotmark
A logical value indicating whether "marks" should be
represented as dots.
- add.image
A logical value indicating whether to add a background
image, when one is available (see GraphSpace).