Skip to contents

PathwaySpace extends the GraphSpace class with signal projection slots. It stores projected signal matrices, projection parameters, and workflow status, and is the main object used by the PathwaySpace package.

Value

A PathwaySpace object.

Slots

nodes

Inherited from GraphSpace.

edges

Inherited from GraphSpace.

graph

Inherited from GraphSpace.

image

Inherited from GraphSpace.

fdata

Inherited from GraphSpace.

pars

Inherited from GraphSpace.

misc

Inherited from GraphSpace.

uuid

Inherited from GraphSpace.

projection

A SpaceProjection object storing the intermediate and final matrices produced by a projection method.

pars_ps

A list with PathwaySpace parameters.

status

A vector containing the processing status of the PathwaySpace object.

Constructor

See buildPathwaySpace.

Author

Sysbiolab Team, Mauro Castro (mauro.castro@ufpr.br)