PathwaySpace: Spatial Projection of Network Signals along Geodesic Paths
Source:R/pspace-misc.R
PathwaySpace-package.RdFor a given graph containing vertices, edges, and a signal associated with the vertices, the 'PathwaySpace' package performs a convolution operation, which involves a weighted combination of neighboring vertices and their associated signals. The package uses a decay function to project these signals, creating geodesic paths on a 2D-image space. 'PathwaySpace' has various applications, such as visualizing network data in a graphical format that highlights the relationships and signal strengths between vertices. By combining graph theory, signal processing, and visualization, 'PathwaySpace' provides a way of representing graph data on a continuous projection space. Based on methods introduced in Tercan et al. (2025) doi:10.1016/j.xpro.2025.103681 and Ellrott et al. (2025) doi:10.1016/j.ccell.2024.12.002 .
Details
For a hands-on introduction, see the vignette:
vignette("PathwaySpace").
The full set of documented topics can also be browsed in HTML by
running help.start() and selecting the PathwaySpace package
from the package list.
Author
Maintainer: Mauro Castro mauro.a.castro@gmail.com (ORCID)
Authors:
Sysbiolab Team
Other contributors:
Victor Apolonio [contributor]
Jonathan Back [contributor]
Lana Querne [contributor]
Vinicius Chagas [contributor]
Bahar Tercan [contributor]