Retrieves the nearest neighbor for each node from a PathwaySpace object using Euclidean distance.
Arguments
- ps
Either a PathwaySpace or GraphSpace object.
Retrieves the nearest neighbor for each node from a PathwaySpace object using Euclidean distance.
Either a PathwaySpace or GraphSpace object.