Learn R Programming

PathwaySpace (version 1.1.1)

pspace.pals: Create interpolated color palettes for PathwaySpace images

Description

Creates mixed color palettes by interpolating and offsetting hues, useful for generating transitions between hues.

Usage

pspace.pals(
  colors = c("#303f9d", "#578edb", "#63b946", "#f3930c", "#a60d0d"),
  trim.colors = c(3, 2, 1, 2, 3),
  offset = 0.5,
  n = 25
)

Value

A vector with hexadecimal color codes.

Arguments

colors

A vector of five base colors used to construct the custom diverging palette. These colors are interpolated according to the `trim.colors` values.

trim.colors

A vector of five positive integers that control the relative weight of each hue in the five-color diverging palette.

offset

Adjusts brightness by shifting hues toward the center, either brighter (`offset > 0`) or darker (` offset < 0`).

n

The number of colors to generate in the output palette.

See Also

plotPathwaySpace

Examples

Run this code
pspace.pals()

Run the code above in your browser using DataLab