powered by
Creates mixed color palettes by interpolating and offsetting hues, useful for generating transitions between hues.
pspace.pals( colors = c("#303f9d", "#578edb", "#63b946", "#f3930c", "#a60d0d"), trim.colors = c(3, 2, 1, 2, 3), offset = 0.5, n = 25 )
A vector with hexadecimal color codes.
A vector of five base colors used to construct the custom diverging palette. These colors are interpolated according to the `trim.colors` values.
A vector of five positive integers that control the relative weight of each hue in the five-color diverging palette.
Adjusts brightness by shifting hues toward the center, either brighter (`offset > 0`) or darker (` offset < 0`).
The number of colors to generate in the output palette.
plotPathwaySpace
pspace.pals()
Run the code above in your browser using DataLab