Signal aggregation functions for circularProjection
and polarProjection internal calls. The aggregation should be
symmetric with respect to signal polarity, ensuring that opposite signals
produce corresponding outputs.
Usage
signalAggregation(method = c("mean", "wmean", "log.wmean", "exp.wmean"))Arguments
- method
A character string specifying the method for signal aggregation, returning either a customized
meanorweighted.meanfunction.