The summitMapping method implements a segmentation
strategy to identify summits on a 2D-landscape image
(see summitWatershed).
Usage
# S4 method for class 'PathwaySpace'
summitMapping(
ps,
maxset = 30,
minsize = 30,
threshold = 0.5,
segm.fun = summitWatershed,
...
)Arguments
- ps
A PathwaySpace class object.
- maxset
A single positive integer indicating the maximum number of summits to be returned by the segmentation function.
- minsize
A single positive integer indicating the minimum size of the summits.
- threshold
A threshold provided as a fraction (in
[0,1]) of the max signal intensity.- segm.fun
A segmentation function used to detect summits (see
summitWatershed).- ...
Additional arguments passed to the segmentation function.
Value
A preprocessed PathwaySpace class object.
Examples
library(PathwaySpace)
# Load a large igraph
data("PCv12_pruned_igraph", package = "PathwaySpace")
# Continue this example from the PathwaySpace vignette,
# in the 'PathwaySpace decoration' section